@@ -84,6 +84,26 @@ func TestChallengeTLS_Run_Domains(t *testing.T) {
 	}
 }
 
+func TestChallengeTLS_Run_IP(t *testing.T) {
+	loader.CleanLegoFiles()
+
+	output, err := load.RunLego(
+		"-m", "hubert@hubert.com",
+		"--accept-tos",
+		"-s", "https://localhost:14000/dir",
+		"-d", "127.0.0.1",
+		"--tls",
+		"--tls.port", ":5001",
+		"run")
+
+	if len(output) > 0 {
+		fmt.Fprintf(os.Stdout, "%s\n", output)
+	}
+	if err != nil {
+		t.Fatal(err)
+	}
+}
+
 func TestChallengeTLS_Run_CSR(t *testing.T) {
 	loader.CleanLegoFiles()
 
@@ -263,8 +283,8 @@ func TestChallengeHTTP_Client_Registration_QueryRegistration(t *testing.T) {
 	require.NotNil(t, resource)
 
 	assert.Equal(t, "valid", resource.Body.Status)
-	assert.Regexp(t, `https://localhost:14000/list-orderz/\d+`, resource.Body.Orders)
-	assert.Regexp(t, `https://localhost:14000/my-account/\d+`, resource.URI)
+	assert.Regexp(t, `https://localhost:14000/list-orderz/[\w\d]+`, resource.Body.Orders)
+	assert.Regexp(t, `https://localhost:14000/my-account/[\w\d]+`, resource.URI)
 }
 
 func TestChallengeTLS_Client_Obtain(t *testing.T) {
